/*************************************************************************
 * odil - Copyright (C) Universite de Strasbourg
 * Distributed under the terms of the CeCILL-B license, as published by
 * the CEA-CNRS-INRIA. Refer to the LICENSE file or to
 * http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html
 * for details.
 ************************************************************************/

#ifndef _5382f5e0_e993_4966_9447_542844edb635
#define _5382f5e0_e993_4966_9447_542844edb635

#include <log4cpp/Category.hh>
#include <log4cpp/Priority.hh>

#define ODIL_LOG(level) \
    log4cpp::Category::getInstance("odil") << log4cpp::Priority::level

#endif // _5382f5e0_e993_4966_9447_542844edb635
